<?php

/**
 * @file
 * Report_field.admin.inc.
 */

/**
 * Field List configuration form.
 */
function report_field_form($form, &$form_state) {
  $node_types = node_type_get_types();
  foreach ($node_types as $node_type) {
    $fields = field_info_instances('node', $node_type->type);
    if (count($fields) > 0) {
      $content_type = 'report_field_' . $node_type->type;
      $form[$content_type] = array(
        '#type' => 'container',
        '#attributes' => array(
          'id' => array($content_type),
        ),
      );
      $form[$content_type]['text'] = array(
        '#markup' => '<h2>' . $node_type->name . '</h2>',
      );
    }
    foreach ($fields as $field) {
      $item = 'report_field_' . $node_type->type . '_' . $field['field_name'];
      $form[$content_type][$item] = array(
        '#prefix' => '<div id="' . $item . '">',
        '#suffix' => '</div>',
        '#tree' => TRUE,
        '#theme' => 'table',
        '#rows' => array(),
        '#attributes' => array(
          'class' => array('inner-table'),
          'id' => array($item),
        ),
      );
      $title = check_plain($field['label']);
      $variable_get_array = variable_get($item, array());
      $checkbox = array(
        '#type' => 'checkbox',
        '#title' => $title,
        '#default_value' => (!empty($variable_get_array[0][$item . '_checkbox'])) ? $variable_get_array[0][$item . '_checkbox'] : 0,
        '#attributes' => array('class' => array('report-field-field-checkbox')),
      );
      $label = array(
        '#type' => 'textfield',
        '#title' => t('Label'),
        '#default_value' => (!empty($variable_get_array[1][$item . '_label'])) ? $variable_get_array[1][$item . '_label'] : '',
        '#size' => 50,
        '#maxlength' => 255,
        '#states' => array(
          'visible' => array(
            ':input[name="' . $item . '[0][' . $item . '_checkbox]"]' => array('checked' => TRUE),
          ),
          'required' => array(
            ':input[name="' . $item . '[0][' . $item . '_checkbox]"]' => array('checked' => TRUE),
          ),
        ),
      );
      $reported = array(
        '#type' => 'textfield',
        '#title' => t('Reported'),
        '#default_value' => (!empty($variable_get_array[1][$item . '_reported'])) ? $variable_get_array[1][$item . '_reported'] : '',
        '#size' => 50,
        '#maxlength' => 255,
        '#states' => array(
          'visible' => array(
            ':input[name="' . $item . '[0][' . $item . '_checkbox]"]' => array('checked' => TRUE),
          ),
          'required' => array(
            ':input[name="' . $item . '[0][' . $item . '_checkbox]"]' => array('checked' => TRUE),
          ),
        ),
      );
      $message = array(
        '#type' => 'checkbox',
        '#title' => t('Message field?'),
        '#default_value' => (!empty($variable_get_array[1][$item . '_message'])) ? $variable_get_array[1][$item . '_message'] : 0,
        '#states' => array(
          'visible' => array(
            ':input[name="' . $item . '[0][' . $item . '_checkbox]"]' => array('checked' => TRUE),
          ),
        ),
      );
      $form[$content_type][$item][] = array(
        $item . '_checkbox' => &$checkbox,
      );
      $form[$content_type][$item][] = array(
        $item . '_label' => &$label,
        $item . '_reported' => &$reported,
        $item . '_message' => &$message,
      );
      $form[$content_type][$item]['#rows'][] = array(
        array(
          'data' => &$checkbox,
          'colspan' => 3,
        ),
      );
      $form[$content_type][$item]['#rows'][] = array(
        array('data' => &$label),
        array('data' => &$reported),
        array('data' => &$message),
      );
      unset($checkbox);
      unset($label);
      unset($reported);
      unset($message);
    }
  }
  return system_settings_form($form);
}

/**
 * Validate configuration form.
 */
function report_field_form_validate($form, &$form_state) {
  foreach ($form_state['values'] as $key => $value) {
    if (is_array($value) && $value[0][$key . '_checkbox'] == 1) {
      if (preg_replace('/\s+/', '', $value[1][$key . '_label']) == '') {
        form_set_error($key . '][1][' . $key . '_label', t('Label field can not be empty!'));
      }
      if (preg_replace('/\s+/', '', $value[1][$key . '_reported']) == '') {
        form_set_error($key . '][1][' . $key . '_reported', t('Reported field can not be empty!'));
      }
    }
  }
}

/**
 * Reported Fields form.
 */
function report_field_form_reading_db($form, &$form_state) {
  $result = db_select('report_field_invalid_fields', 'n')
      ->fields('n')
      ->execute()
      ->fetchAllAssoc('rid');
  $header = array('Rid', 'Uid', 'Email', 'Message', 'Reported Field',
    'Reported Field Title', 'Reported Content Type', 'Node ID', 'Node Title',
    'Status', 'Hash', 'Time', 'Delete Record');
  $form['records'] = array(
    '#prefix' => '<div id="records">',
    '#suffix' => '</div>',
    '#tree' => TRUE,
    '#theme' => 'table',
    '#header' => $header,
    '#rows' => array(),
  );
  if (!empty($result)) {
    foreach ($result as $db_record) {
      $rid = array(
        '#markup' => $db_record->rid,
      );
      $uid = array(
        '#markup' => $db_record->uid,
      );
      $email = array(
        '#markup' => check_plain($db_record->email),
      );
      $message = array(
        '#markup' => check_plain($db_record->message),
      );
      $reported_field = array(
        '#markup' => $db_record->reported_field,
      );
      $reported_field_title = array(
        '#markup' => $db_record->reported_field_title,
      );
      $reported_content_type = array(
        '#markup' => $db_record->reported_content_type,
      );
      $node_id = array(
        '#markup' => $db_record->node_id,
      );
      $node_title = array(
        '#markup' => $db_record->node_title,
      );
      $status = array(
        '#markup' => $db_record->status,
      );
      $hash = array(
        '#markup' => $db_record->hash,
      );
      $time = array(
        '#markup' => $db_record->time,
      );
      $checkbox = array(
        '#type' => 'checkbox',
        '#title' => '',
        '#default_value' => 0,
      );
      $form['records'][] = array(
        'rid' => &$rid,
        'uid' => &$uid,
        'email' => &$email,
        'message' => &$message,
        'reported_field' => &$reported_field,
        'reported_field' => &$reported_field_title,
        'reported_content_type' => &$reported_content_type,
        'node_id' => &$node_id,
        'node_title' => &$node_title,
        'status' => &$status,
        'hash' => &$hash,
        'time' => &$time,
        $db_record->rid . '_checkbox' => &$checkbox,
      );
      $form['records']['#rows'][] = array(
        array('data' => &$rid),
        array('data' => &$uid),
        array('data' => &$email),
        array('data' => &$message),
        array('data' => &$reported_field),
        array('data' => &$reported_field_title),
        array('data' => &$reported_content_type),
        array('data' => &$node_id),
        array('data' => &$node_title),
        array('data' => &$status),
        array('data' => &$hash),
        array('data' => &$time),
        array('data' => &$checkbox),
      );
      unset($rid);
      unset($uid);
      unset($email);
      unset($message);
      unset($reported_field);
      unset($reported_field_title);
      unset($reported_content_type);
      unset($node_id);
      unset($node_title);
      unset($status);
      unset($hash);
      unset($time);
      unset($checkbox);
    }
    $form['submit'] = array(
      '#type' => 'submit',
      '#value' => t('Save'),
    );
  }
  else {
    $no_record = array(
      '#markup' => '<center><strong>' . t('NO REPORTED FIELDS FOUND') . '</strong></center>',
    );
    $form['records']['#rows'][] = array(
      array('data' => &$no_record, 'colspan' => 13)
    );
    unset($no_record);
  }
  return $form;
}

/**
 * Reported Fields form validation.
 */
function report_field_form_reading_db_validate($form, &$form_state) {
  if (isset($form_state['values']['records'])) {
    $array = $form_state['values']['records'];
    foreach ($array as $array_index) {
      while (($index = current($array_index)) !== FALSE) {
        if ($index == 1) {
          $key = key($array_index);
          $key_trimmed = str_replace('_checkbox', '', $key);
          db_delete('report_field_invalid_fields')
              ->condition('rid', $key_trimmed)
              ->execute();
        }
        next($array_index);
      }
    }
  }
}

/**
 * Additional settings form.
 */
function report_field_additional_settings($form, &$form_state) {
  $form['days'] = array(
    '#type' => 'textfield', 
    '#title' => t('Delete pending requests after:'), 
    '#default_value' => variable_get('report_field_delete_pending_requests_time', 7), 
    '#size' => 3, 
    '#maxlength' => 3, 
    '#required' => TRUE,
    '#description' => 'Number of days after which pending request will be deleted.',
  );
  return system_settings_form($form);
}

/**
 * Additional settings form validation.
 */
function report_field_additional_settings_validate($form, &$form_state) {
  if ($form_state['values']['days'] != '' && $form_state['values']['days'] > 0) {
    variable_set('report_field_delete_pending_requests_time', $form_state['values']['days']);
  }
  else {
    form_set_error('days', t('Number of days must be positive integer!'));
    variable_set('report_field_delete_pending_requests_time', 7);
  }
}
